@@ -584,12 +584,12 @@ public:
     return infoList;
   }
 
-  ProviderInterfacePtr createProvider(const QString& name) const
+  ProviderInterface* createProvider(const QString& name) const
   {
     if ( name == "o2_germany" )
-      return ProviderInterfacePtr(new o2Germany);
+      return new o2Germany;
     
-    return ProviderInterfacePtr();
+    return NULL;
   }
 
 protected:
