@@ -35,9 +35,6 @@
 // Forward declarations
 class ProviderInterface;
 
-// Type definitions
-typedef QSharedPointer<ProviderInterface> ProviderInterfacePtr;
-
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -45,23 +42,33 @@ typedef QSharedPointer<ProviderInterface> ProviderInterfacePtr;
 /// Simple ProviderInfo structure ... may be (re)moved
 struct PROVIDERS_API ProviderInfo
 {
+  enum ProviderType
+  {
+    Free = 1,
+    Payment = 2,
+    FreeAndPayment = Free | Payment
+  };
+
   ProviderInfo()
   {}
 
   ProviderInfo(const QString& visibleName_,
                const QString& providerId_,
                const QIcon& icon_,
-               QLocale::Country country_)
+               QLocale::Country country_,
+               ProviderType type_ = Payment)
   : visibleName(visibleName_)
   , providerId(providerId_)
   , icon(icon_)
   , country(country_)
+  , type(type_)
   {}
 
   QString visibleName;
   QString providerId;
   QIcon icon;
   QLocale::Country country;
+  ProviderType type;
 };
 
 //////////////////////////////////////////////////////////////////////////
